==> mod_auth_tkt-1.3.10.tar.gz: mod_auth_tkt-1.3.10/tools/tkt_cookie.c <==
/* ********************************************************************* *
  tag: sample ticket generator for mod_auth_tkt
 * ********************************************************************* */


/* =======================================================================
 *	 Copyright (c) 2000 Liquid Digital Information Systems, Inc. 
 *	 All rights reserved. 
 *	 This software was written for Liquid Digital Information Systems, Inc. 
 *	 by Raimondas Kiveris and is hereby contributed to the Apache Software 
 *	 Foundation for distribution under the Apache license, as follows.
 *	
 *	 Redistribution and use in source and binary forms, with or without
 *	 modification, are permitted provided that the following conditions
 *	 are met:
 *	
 *	 1. Redistributions of source code must retain the above copyright
 *		 notice, this list of conditions and the following disclaimer. 
 *	
 *	 2. Redistributions in binary form must reproduce the above copyright
 *		 notice, this list of conditions and the following disclaimer in
 *		 the documentation and/or other materials provided with the
 *		 distribution.
 *	
 *	 3. All advertising materials mentioning features or use of this
 *		 software must display the following acknowledgment:
 *		 "This product includes software developed by the Apache Group
 *		 for use in the Apache HTTP server project (http://www.apache.org/)."
 *	
 *	 4. The names "Apache Server" and "Apache Group" must not be used to
 *		 endorse or promote products derived from this software without
 *		 prior written permission. For written permission, please contact
 *		 apache@apache.org.
 *	
 *	 5. Products derived from this software may not be called "Apache"
 *		 nor may "Apache" appear in their names without prior written
 *		 permission of the Apache Group.
 *	
 *	 6. Redistributions of any form whatsoever must retain the following
 *		 acknowledgment:
 *		 "This product includes software developed by the Apache Group
 *		 for use in the Apache HTTP server project (http://www.apache.org/)."
 *	
 *	 THIS SOFTWARE IS PROVIDED BY THE APACHE GROUP ``AS IS'' AND ANY
 *	 EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *	 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *	 PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE APACHE GROUP OR
 *	 ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *	 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *	 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *	 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *	 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *	 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *	 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 *	 OF THE POSSIBILITY OF SUCH DAMAGE.
 *	 =======================================================================
 *	
 *	 This software consists of voluntary contributions made by many
 *	 individuals on behalf of the Apache Group and was originally based
 *	 on public domain software written at the National Center for
 *	 Supercomputing Applications, University of Illinois, Urbana-Champaign.
 *	 For more information on the Apache Group and the Apache HTTP server
 *	 project, please see <http://www.apache.org/>.
 *	
 * ======================================================================
 */

#include <string.h>
#include <stdio.h>

#include "ap_config.h"
#include "ap.h"

#include "../src/tkt_digest.h"

#define USAGE "%s -i <ip_address> -k <host_key> -u <user_id> -d <data> [-b]\n\tUse -b to scramble (Base64) the result\n\n"

int main (int argc, char** argv) 
{
  char * ip_address = NULL;
  char * user_id = NULL;
  char * key = NULL;
  char * data = NULL;
  int base64 = 0;
  char buf[640];
  char *cookie;

  char c;
  extern char *optarg;
  extern int optind;
  int errflg = 0;
  unsigned int timestamp = time(NULL);

  char *digest;

  while ((c = getopt(argc, argv, "i:u:k:d:t:b")) != EOF)
    switch (c) {
    case 'i':
      ip_address = optarg;
      break;
    case 'u':
      user_id = optarg;
      break;
    case 'k':
      key = optarg;
      break;
    case 'd':
      data = optarg;
      break;
    case 'b':
      base64 = 1;
      break;
    case 't':
      timestamp = strtol(optarg, NULL, 10);
      break;
    case '?':
      errflg++;
      break;
    default: 
      errflg++;
      break;
    }
  if (errflg || ip_address == NULL || user_id == NULL || key == NULL || data == NULL) {
    (void)fprintf(stderr, USAGE, argv[0]);
    exit (2);
  }

  
  /* TODO: add token support */
  digest = tkt_digest(ip_address, key, user_id, "", data, timestamp);


  /* Construct the cookie  */
  memcpy (buf, digest, 32);
  sprintf(&buf[32], "%08x%s!%s", timestamp, user_id, data);
  

  if (base64) {
    char *copy = strdup (buf);
    ap_base64encode(buf, copy, strlen(copy));
    free(copy);
  }
  cookie = buf;

  printf ("%s\n",  cookie);
  fflush(stdout);
  
  return (0);
}

==> mod_auth_tkt-1.3.11.tar.gz: mod_auth_tkt-1.3.11/tools/tkt_cookie.c <==
/* ********************************************************************* *
  tag: sample ticket generator for mod_auth_tkt
 * ********************************************************************* */


/* =======================================================================
 *	 Copyright (c) 2000 Liquid Digital Information Systems, Inc. 
 *	 All rights reserved. 
 *	 This software was written for Liquid Digital Information Systems, Inc. 
 *	 by Raimondas Kiveris and is hereby contributed to the Apache Software 
 *	 Foundation for distribution under the Apache license, as follows.
 *	
 *	 Redistribution and use in source and binary forms, with or without
 *	 modification, are permitted provided that the following conditions
 *	 are met:
 *	
 *	 1. Redistributions of source code must retain the above copyright
 *		 notice, this list of conditions and the following disclaimer. 
 *	
 *	 2. Redistributions in binary form must reproduce the above copyright
 *		 notice, this list of conditions and the following disclaimer in
 *		 the documentation and/or other materials provided with the
 *		 distribution.
 *	
 *	 3. All advertising materials mentioning features or use of this
 *		 software must display the following acknowledgment:
 *		 "This product includes software developed by the Apache Group
 *		 for use in the Apache HTTP server project (http://www.apache.org/)."
 *	
 *	 4. The names "Apache Server" and "Apache Group" must not be used to
 *		 endorse or promote products derived from this software without
 *		 prior written permission. For written permission, please contact
 *		 apache@apache.org.
 *	
 *	 5. Products derived from this software may not be called "Apache"
 *		 nor may "Apache" appear in their names without prior written
 *		 permission of the Apache Group.
 *	
 *	 6. Redistributions of any form whatsoever must retain the following
 *		 acknowledgment:
 *		 "This product includes software developed by the Apache Group
 *		 for use in the Apache HTTP server project (http://www.apache.org/)."
 *	
 *	 THIS SOFTWARE IS PROVIDED BY THE APACHE GROUP ``AS IS'' AND ANY
 *	 EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *	 IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *	 PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE APACHE GROUP OR
 *	 ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *	 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 *	 NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *	 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *	 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *	 STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 *	 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 *	 OF THE POSSIBILITY OF SUCH DAMAGE.
 *	 =======================================================================
 *	
 *	 This software consists of voluntary contributions made by many
 *	 individuals on behalf of the Apache Group and was originally based
 *	 on public domain software written at the National Center for
 *	 Supercomputing Applications, University of Illinois, Urbana-Champaign.
 *	 For more information on the Apache Group and the Apache HTTP server
 *	 project, please see <http://www.apache.org/>.
 *	
 * ======================================================================
 */

#include <string.h>
#include <stdio.h>

#include "ap_config.h"
#include "ap.h"

#include "../src/tkt_digest.h"

#define USAGE "%s -i <ip_address> -k <host_key> -u <user_id> -d <data> [-b]\n\tUse -b to scramble (Base64) the result\n\n"

int main (int argc, char** argv) 
{
  char * ip_address = NULL;
  char * user_id = NULL;
  char * key = NULL;
  char * data = NULL;
  int base64 = 0;
  char buf[640];
  char *cookie;

  char c;
  extern char *optarg;
  extern int optind;
  int errflg = 0;
  unsigned int timestamp = time(NULL);

  char *digest;

  while ((c = getopt(argc, argv, "i:u:k:d:t:b")) != EOF)
    switch (c) {
    case 'i':
      ip_address = optarg;
      break;
    case 'u':
      user_id = optarg;
      break;
    case 'k':
      key = optarg;
      break;
    case 'd':
      data = optarg;
      break;
    case 'b':
      base64 = 1;
      break;
    case 't':
      timestamp = strtol(optarg, NULL, 10);
      break;
    case '?':
      errflg++;
      break;
    default: 
      errflg++;
      break;
    }
  if (errflg || ip_address == NULL || user_id == NULL || key == NULL || data == NULL) {
    (void)fprintf(stderr, USAGE, argv[0]);
    exit (2);
  }

  
  /* Construct the cookie  */
  /* TODO: add token support */
  digest = tkt_digest(ip_address, key, user_id, "", data, timestamp);
  ap_snprintf(buf, sizeof buf, "%s%08x%s!%s", digest, timestamp, user_id, data);

  if (base64) {
    char *copy = strdup (buf);
    ap_base64encode(buf, copy, strlen(copy));
    free(copy);
  }
  cookie = buf;

  printf ("%s\n",  cookie);
  fflush(stdout);
  
  return (0);
}
